#!/bin/sh

# Finds programs recorded since given timestamp (matched on when .ts file was last
# modified) and logs details.
#
# @param 1       Timestamp in format "yyyy-mm-dd hh:mi:ss" to be used for cutoff.
#                Defaults to beginning of yesterday if not specified.
#
# @version 1.0.39   08 Sep 2020.

rootdir=/media/Video
rootdir2=/mnt/hd3/Video
logfile=/opt/tmp/rsrecmon.log
logfile2=/opt/tmp/rs_process.log
trcfile=/opt/tmp/rsrecmon.trc
errfile=/opt/tmp/rsrecmon.err
mvrep=/opt/tmp/rsrecmon.mov
findtmp=/opt/tmp/find.tmp
#startstopdiff=300
startstopdiff=500
hasnewk=0

if [ -f /opt/webif/plugin/Newk/Newk.conf ]; then
  if grep -q AUTO /opt/webif/plugin/Newk/Newk.conf; then
    hasnewk=1
  fi
fi

log () {
  echo `date +"%Y-%m-%d %T"` $1 | tee -a $logfile $trcfile
  echo `date +"%d/%m/%Y %T"` "- $1" >> $activityfile
  $rs_log "$1"
}

transliterate() {
  if [ "$trcfile" != "" ]; then
    echo "transliterate($1)" >> $trcfile
  fi

  result="`echo \"$1\" | sed \"s/:/_/g\"`"
  result="`echo \"$result\" | sed \"s/\//_/g\"`"
  result="`echo \"$result\" | sed \"s/&/_/g\"`"
  result="`echo \"$result\" | sed \"s/*/_/g\"`"
  result="`echo \"$result\" | sed \"s/?/_/g\"`"
  result="`echo \"$result\" | sed \"s/(/_/g\"`"
  result="`echo \"$result\" | sed \"s/)/_/g\"`"
  result="`echo \"$result\" | sed \"s/\.\.\./___/g\"`"
  if [ $hasnewk -eq 1 ]; then
    result="`echo \"$result\" | sed \"s/New: //g\"`"
    result="`echo \"$result\" | sed \"s/New://g\"`"
  fi
  #result="`echo \"$result\" | sed \"s/'/_/g\"`"

 if [ "$result" != "$1" -a "$trcfile" != "" ]; then
   echo `date +"%Y-%m-%d %T"`: \""$1"\" transliterated to \""$result"\" >> $trcfile
 fi

 echo "$result"
}

move_thumbnail_folder () {
  echo "Checking thumbnail folder \"$1\" for existence" | tee -a $trcfile $errfile
  if [ -d "$1" ]; then
    echo "Moving thumbnail folder \"$1\" to \"$2\"" | tee -a $logfile $trcfile
    mv "$1" "$2"
    if [ -d "$1" ]; then
      # Failed to move, target already exists, remove source.
      rm "$1/"* > /dev/null
      rmdir "$1" > /dev/null
    fi
  fi
}

echo `date +"%Y-%m-%d %T"` rsrecmon "$1" started >> $logfile

if [ "$1" != "" ]; then
  cutoff="$1"
else
  now=`date +"%s"`
  endofyesterday=$(($now - $now % 86400 - 1))
  now_minus_1_day=$(($now - 86400))
  cutoff="`date -d @$now_minus_1_day +\"%Y-%m-%d\"` 00:00:00"
fi
echo "cutoff=$cutoff" >> $trcfile

activityfile=/opt/tmp/activity.log
rs_log="rs log"
starttimefield=7
stoptimefield=9

erase_file() {
  file_path_name="$1"
  if [ -f "$file_path_name" ]; then
    file_size_bytes=`stat -c "%s" "$file_path_name"`
    file_size_hr=`echo $file_size_bytes | rsbs2hr.sh`
    rm "$file_path_name"
    file_count=`expr $file_count + 1`
    file_size_total_bytes=`expr $file_size_total_bytes + $file_size_bytes`
    echo `date +"%Y-%m-%d %T"` "  Deleted dummy recording file '$file_path_name' ($file_size_hr)" | tee -a $logfile
  else
    echo `date +"%Y-%m-%d %T"` "  Dummy recording file '$file_path_name' not found" | tee -a $logfile
  fi
}

# Check postfixes for empty synopses.
empty_synopses=`sqlite3 /opt/etc/rsqueue.db "select * from postfixes where synopsis is null or length(synopsis) = 0 order by title, starttime;"`
echo "$empty_synopses" | while read pf; do
  if [ "$pf" == "" ]; then
    continue;
  fi

  echo `date +"%Y-%m-%d %T"` "Warning: Empty synopsis for postfix \"$pf"\" | tee -a $logfile $errfile
done

# Move [Dummy * recordings in root to [Dummies] folder.
files3=`find "/mnt/hd3/Video/" -maxdepth 1 -mmin +1 -name "\[Dummy*.ts" -print`
echo "$files3" | while read f; do
  if [ "$f" == "*.ts" -o "$f" == "" ]; then
    continue;
  fi

  basename="${f%.ts}"
  hmt=`hmt -p "$basename.hmt" | sed ':a;N;$!ba;s/\n/ /g'`
  title=`echo "$hmt" | cut -f1`

  dummy=`expr substr "$title" 1 7`
  is_dummy=0
  fixed_folder=""
  filename="$f"
  
  if [ "$dummy" = "[Dummy " ]; then
    # Dummy, move to [Dummies] if not already there.
    echo "$filename" is dummy | tee -a $logfile $trcfile

    is_dummy=1
    folder="/mnt/hd3/Video/[Dummies]"
    if [ ! -d "$folder" ]; then
      echo "Creating folder \"$folder\"" | tee -a $logfile $trcfile
      mkdir "$folder"
    fi

    filebasename="${basename##*/}"
    dirname="$(dirname "$filename")"

    echo dirname="$dirname" | tee -a $logfile $trcfile

    echo `date +"%Y-%m-%d %T"` "Dummy find source:" | tee -a $errfile
    ls -al "$f" 2>&1 | tee -a $errfile
    if [ "$dirname" != "/media/Video/[Dummies]" -a "$dirname" != "/mnt/hd3/Video/[Dummies]" -a "$dirname" != "[Dummies]" ]; then
      echo `date +"%Y-%m-%d %T"`: "Moving dummy recording \"$basename\" to \"$folder\"..." | tee -a $logfile $trcfile $errfile
      echo `date +"%Y-%m-%d %T"`: "Dummy source \"/mnt/hd3/Video\":" >> $errfile
      ls -al "$basename"* 2>&1 | tee -a $errfile
      echo `date +"%Y-%m-%d %T"`: "Dummy target \"/mnt/hd3/Video/[Dummies]\" (should be empty)::" >> $errfile
      ls -al "$folder/$filebasename"* 2>&1 | tee -a $errfile
      hmt +setfilename="$folder/$filebasename" "$basename.hmt" 2>> $errfile
      mv "$basename.hmt" "$folder" 2>> $errfile
      mv "$basename.nts" "$folder" 2>> $errfile
      mv "$basename.ts" "$folder" 2>> $errfile
      if [ -f "$basename.thm" ]; then
        mv "$basename.thm" "$folder" 2>> $errfile
      fi

      move_thumbnail_folder "$dirname/.$filebasename" "$folder" 2>> $errfile
      
      echo `date +"%Y-%m-%d %T"`"|$filebasename|[Dummies]/$filebasename" >> $mvrep

      echo "Dummy .hmt file modified, 3+ files moved" >> $trcfile
      echo `date +"%d/%m/%Y %T"` - Moved files: \"$basename\" to \"$folder\" >> $activityfile
      $rs_log "Moved recording \"$filebasename\" to dummy folder \"$folder\""
    else
      echo "Dummy .hmt file already in [Dummies], 0 files moved" >> $trcfile
    fi
  fi
done

# Remove defunct .hmt files - seems to relate to files moved but Media List cache holding a copy
# somewhere pointing to the original location, hence creating an .hmt of size 0 or 1077 bytes if
# not found in file system.

files3=`find /mnt/hd3/Video -type f -size 0 -name "*.hmt" ; find /mnt/hd3/Video -type f -size 1077c -name "*.hmt"`
echo "$files3" | while read f; do
  if [ "$f" == "*.hmt" -o "$f" == "" ]; then
    continue;
  fi

  basename="${f%.hmt}"

  if [ ! -f "$basename.ts" -a ! -f "$basename.nts" ]; then
    echo `date +"%Y-%m-%d %T"` "Defunct .hmt file \"$f\" found:" | tee -a $logfile $errfile
    ls -al "$basename"* | tee -a $logfile $errfile
    if [ -s "$f" ]; then
      hexdump -C "$f" | tee -a $logfile $errfile
    fi
    basename2=`basename "$basename"`
    moved=`grep -F "|$basename2|" $mvrep`
    if [ "$moved" != "" ]; then
      when=`echo "$moved" | cut -d "|" -f 1`
      source=`echo "$moved" | cut -d "|" -f 2`
      target=`echo "$moved" | cut -d "|" -f 3`
      echo `date +"%Y-%m-%d %T"` "Defunct .hmt file \"$source\" was moved to \"$target\" at $when, safe to remove" | tee -a $logfile $errfile
    
      rm "$f" 2>> $errfile
      echo `date +"%Y-%m-%d %T"` "Defunct .hmt file \"$f\" removed" | tee -a $errfile
      $rs_log "Defunct .hmt file \"$source\" was moved to \"$target\" at $when, safe to remove"
      $rs_log "Defunct .hmt file \"$f\" removed"
    else
      if [ -s "$f" ]; then
        recstatus=`dd if="$f" ibs=1 skip=872 2> /dev/null | hexdump -C | cut -b12-12 | head -n 1`
        echo "recstatus=$recstatus" >> $trcfile
        if [ "$recstatus" = "0" ]; then
          echo `date +"%Y-%m-%d %T"` "Defunct .hmt file \"$f\" appears to be a cached, successful recording, remove" | tee -a $logfile $errfile
          rm "$f" 2>> $errfile
          echo `date +"%Y-%m-%d %T"` "Defunct .hmt file \"$f\" removed" | tee -a $errfile
          $rs_log "Defunct .hmt file \"$f\" appears to be a cached, successful recording, remove"
          $rs_log "Defunct .hmt file \"$f\" removed"
        elif [ "$recstatus" = "5" ]; then
          logtext="Failed recording \"$basename2\" - conflict with higher priority"
          if [ `grep -F -c "$logtext" $activityfile` -eq 0 ]; then
            log "$logtext"
          fi
        elif [ "$recstatus" = "7" ]; then
          logtext="Failed recording \"$basename2\" - failed to track recording (AR)"
          if [ `grep -F -c "$logtext" $activityfile` -eq 0 ]; then
            log "$logtext"
          fi
        else
          logtext="Failed recording \"$basename2\" - unknown failure ($recstatus)"
          if [ `grep -F -c "$logtext" $activityfile` -eq 0 ]; then
            log "$logtext"
          fi
        fi
      fi
      echo `date +"%Y-%m-%d %T"` "Defunct .hmt file \"$f\" appears to be a failed recording" | tee -a $logfile $errfile
    fi
  else
    echo `date +"%Y-%m-%d %T"` "Small .hmt file \"$f\" not defunct:" | tee -a $logfile $errfile
    ls -al "$basename"* | tee -a $logfile $errfile
  fi      
done

if [ "$1" = "-d" ]; then
  exit 0
fi

touch -d "$cutoff" $findtmp
echo `date +"%Y-%m-%d %T"` `ls -ale $findtmp` >> $trcfile
files2=`find /mnt/hd3/Video -type f -newer $findtmp -mmin +1 \( -name "*.ts" -o -name "*.tmp" \) -print0 | xargs -0 ls -tr`
echo "$files2" | while read f; do
  if [ "$f" == "*.ts" -o "$f" == "*.tmp" -o "$f" == "./0.ts" ]; then
    continue;
  fi

  echo `date +"%Y-%m-%d %T"` file="$f" >> $trcfile
  extension="${f##*.}"
    
  if [ "$extension" != "ts" -a "$extension" != "tmp" ]; then
    # Shouldn't happen, but does sometimes anyway.
    continue;
  fi

  # File path name without the extension.
  basename="${f%.$extension}"
  filebasename="${f##*/}"
  # File name without the extension.
  basename2="${filebasename%.ts}"
  #dirname=`dirname "$f" | sed 's#/mnt/hd3/#/media/#'`
  dirname=`dirname "$f" | sed 's#/media/#/mnt/hd3/#'`
  echo "basename=$basename" >> $trcfile
  echo "basename2=$basename2" >> $trcfile
  echo "dirname=$dirname" >> $trcfile

  if [ ! -f "$basename.hmt" ]; then
    # Wrong file, no corresponding .hmt file found, continue.
    continue;
  fi

  # sed needed for replacing LFs by spaces, will completely mess up cut fields otherwise.
  hmt=`hmt -p "$basename.hmt" | sed ':a;N;$!ba;s/\n/ /g'`

  timestamp=`stat -c "%y" "$f"`
  timestamp=`expr substr "$timestamp" 1 19`
  echo `date +"%Y-%m-%d %T"` "Timestamp: $timestamp" >> $trcfile

  channel=`echo "$hmt" | cut -f5`
  lcn=`echo "$hmt" | cut -f4`
  echo "lcn=$lcn" >> $trcfile
  serviceid=`sqlite3 file:/opt/epg/channels.db?mode=ro "select usSvcId from TBL_SVC where usLcn = $lcn";`
  echo "serviceid=$serviceid" >> $trcfile
  if [ "$channel" != "" ]; then
    echo `date +"%Y-%m-%d %T"` "File: \"$f\"" | tee -a $logfile $trcfile
    echo `date +"%Y-%m-%d %T"` "Timestamp: $timestamp" | tee -a $logfile $trcfile

    #echo "channel=$channel" | tee -a $trcfile
    starttime=`echo "$hmt" | cut -f$starttimefield`
    #echo "starttime=$starttime" | tee -a $trcfile
    starttimefmt=`date -u -d @$starttime +"%a %d %h %Y %H:%M:%S"`
    starttimefmt2=`date -u -d @$starttime +"%a %d %h %Y %H:%M"`
    #echo "starttimefmt=$starttimefmt" | tee -a $trcfile
    stoptime=`echo "$hmt" | cut -f$stoptimefield`
    stoptimefmt=`date -u -d @$stoptime +"%a %d %h %Y %H:%M:%S"`
    stoptimeshortfmt=`date -u -d @$stoptime +"%H:%M:%S"`
    duration=$((($stoptime - $starttime) / 60))
    #echo "duration=$duration" | tee -a $trcfile
    title=`echo "$hmt" | cut -f1`
    size=`stat -c "%s" "$basename.$extension"`
    size=`echo $size | rsbs2hr.sh`
    logtext="Recorded: $channel $starttimefmt-$stoptimeshortfmt $title ($duration minutes, $size)"
    if [ `grep -F -c "$logtext" $activityfile` -eq 0 ]; then
      log "$logtext"
      if echo "$title" | egrep -q '^\[Dummy.*\] '; then
        relfilepathname=`echo "${basename}.ts" | sed 's|/mnt/hd3/Video||'`
        logtext="Recording $relfilepathname scheduled for deletion in 7 days"
        if [ `grep -F -c "$logtext" $activityfile` -eq 0 ]; then
          sqlite3 /opt/etc/rsqueue.db "insert into queue(stamp, command_id, command, max_recs, minstamp) values(strftime('%s', 'now'), 0, '0|delete||$relfilepathname', 0, strftime('%s', 'now', '+7 days'));"
          log "$logtext"
        fi
      fi 
    else
      echo `date +"%Y-%m-%d %T"` "$f" already logged | tee -a $logfile $trcfile
    fi

    # Any post processing in queue for this recording?
    #echo "sqlite3 /opt/etc/rsqueue.db \"select title, synopsis, folder from postfixes where serviceid = $serviceid and abs(starttime - $starttime) <= 60 and abs(stoptime - $stoptime) <= 60;\""
    echo "sqlite3 file:/opt/etc/rsqueue.db?mode=ro \"select distinct pf.title, pf.synopsis, ifnull(s.folder, pf.folder) folder from postfixes pf left join series s on s.serviceid = pf.serviceid and (s.scrid = pf.scrid or pf.scrid is null and upper(s.title) = upper(pf.title)) where pf.serviceid = $serviceid and abs(pf.starttime - $starttime) <= $startstopdiff and abs(pf.stoptime - $stoptime) <= $startstopdiff;\" | head -n 1" >> $trcfile
    #postproc=`sqlite3 /opt/etc/rsqueue.db "select title, synopsis, folder from postfixes where serviceid = $serviceid and abs(starttime - $starttime) <= 60 and abs(stoptime - $stoptime) <= 60;"`
    postproc=`sqlite3 file:/opt/etc/rsqueue.db?mode=ro "select distinct pf.title, pf.synopsis, ifnull(s.folder, pf.folder) folder from postfixes pf left join series s on s.serviceid = pf.serviceid and (s.scrid = pf.scrid or pf.scrid is null and upper(s.title) = upper(pf.title)) where pf.serviceid = $serviceid and abs(pf.starttime - $starttime) <= $startstopdiff and abs(pf.stoptime - $stoptime) <= $startstopdiff;" | head -n 1`
    if [ "$postproc" = "" ]; then
      # Fake postproc for series folder if no postfix was found.
      # Doesn't work matching on title if title has been decorated with episode info.
      title2="`echo \"$title\" | sed \"s/'/''/g\" | sed -r 's/(.*)( \([0-9]+\|[0-9]+\:?[0-9]+?\))(.*)/\1\3/'`"
      echo "sqlite3 file:/opt/etc/rsqueue.db?mode=ro \"select distinct folder /*title*/, '', folder from series s where s.serviceid = $serviceid and (s.title like '%$title2%' or s.folder like '%$title2%');\"" >> $trcfile
      postproc=`sqlite3 file:/opt/etc/rsqueue.db?mode=ro "select distinct folder /*title*/, '{FAKE}', folder from series s where s.serviceid = $serviceid and (s.title like '%$title2%' or s.folder like '%$title2%');"`
    fi
    if [ "$postproc" != "" ]; then
      echo "postproc=$postproc" >> $trcfile
      # Post processing, set synopsis, optionally move to series folder.
      pp1=`echo "$postproc" | cut -d\| -f1`
      pp2=`echo "$postproc" | cut -d\| -f2`
      pp3=`echo "$postproc" | cut -d\| -f3`
      echo "pp1=$pp1" >> $trcfile
      echo "pp2=$pp2" >> $trcfile
      echo "pp3=$pp3" >> $trcfile
      #synopsis=`echo "$postproc" | cut -d\| -f2`
      synopsis="$pp2"
      echo "synopsis=$synopsis" >> $trcfile
      synopsis0="`hmt -p "$basename.hmt" | cut -f 2`"
      if [ "$synopsis" != "" -a "$synopsis" != "{FAKE}" -a "$synopsis" != " " -a "$synopsis" != "$synopsis0" ]; then
        echo `date +"%Y-%m-%d %T"` "Fixing synopsis in \"$basename.hmt\"..." >> $errfile
        hmt +setsynopsis="$synopsis" "$basename.hmt" 2>> $errfile
        log "Changed synopsis \"$synopsis\" from \"$synopsis0\" in \"$basename2.hmt\""
      else
        if [ "$synopsis" = "" ]; then
          synopsis_error="Failed to set synopsis \"$synopsis\" in \"$basename2.hmt\": Post processing found but synopsis was empty"
          log "$synopsis_error"
          echo `date +"%Y-%m-%d %T"` "$synopsis_error" | tee -a $logfile $errfile
        fi
      fi

      #folder=`echo "$postproc" | cut -d\| -f3`
      folder="$pp3"
      echo "folder=$folder" >> $trcfile
      folder=`transliterate "$folder"`
      echo "folder=$folder" >> $trcfile
      echo "rootdir/folder=$rootdir/$folder" >> $trcfile
      echo "dirname=$dirname" >> $trcfile
      # if [ "$folder" != "" -a "$rootdir/$folder" != "$dirname" -a "$rootdir2/$folder" != "$dirname" ]; then
      if [ "$folder" != "" -a "$dirname" = "$rootdir2" ]; then
        if [ ! -d "$rootdir2/$folder" ]; then
          mkdir "$rootdir2/$folder"
          log "Created series folder \"$folder\""
        fi
        # Set new file path in .hmt and move all sidecar files.
        echo `date +"%Y-%m-%d %T"` "Moving recording \"$basename2\" to series folder \"$folder\"..." | tee -a $errfile
        #echo `date +"%Y-%m-%d %T"` "Recording source 1 \"$rootdir\":" | tee -a $errfile
        #ls -al "$rootdir/$basename2"* 2>&1 | tee -a $errfile
        echo `date +"%Y-%m-%d %T"` "Recording source \"$rootdir2\":" | tee -a $errfile
        ls -al "$rootdir2/$basename2"* 2>&1 | tee -a $errfile
        echo `date +"%Y-%m-%d %T"` "Recording target \"$folder\" (should be empty):" | tee -a $errfile
        ls -al "$rootdir2/$folder/$basename2"* 2>&1 | tee -a $errfile
        if [ -f "$rootdir2/$basename2.hmt" ]; then
          hmt +setfilename="$rootdir2/$folder/$basename2" "$basename.hmt" 2>> $errfile
          mv "$rootdir2/$basename2.hmt" "$rootdir2/$folder" 2>> $errfile
          mv "$rootdir2/$basename2.nts" "$rootdir2/$folder" 2>> $errfile
          mv "$rootdir2/$basename2.ts" "$rootdir2/$folder" 2>> $errfile

          move_thumbnail_folder "$rootdir2/.$basename2" "$rootdir2/$folder" 2>> $errfile
          
          echo `date +"%Y-%m-%d %T"`"|$basename2|$folder/$basename2" >> $mvrep

          #if [ -d "$rootdir2/.$basename2" ]; then
          #  mv "$rootdir2/.$basename2" "$rootdir2/$folder/.$basename2" 2>> $errfile
          #fi

          log "Moved recording \"$basename2\" to series folder \"$folder\""
        else
          echo `date +"%Y-%m-%d %T"` "Failed to find source recording in source 2 \"$rootdir2\":" >> $errfile
          log "Failed to move recording \"$basename2\" to series folder \"$folder\", source not found"
        fi
      else
        if [ "$folder" != "" ]; then
          echo `date +"%Y-%m-%d %T"` "\"$f\" not in root \"$rootdir2\" but in \"$dirname\", has already been moved to series folder" | tee -a $trcfile $errfile
        else          
          echo `date +"%Y-%m-%d %T"` "\"$f\" was a single event recording and should remain in root \"$rootdir2\"" | tee -a $trcfile $errfile
        fi
      fi

      # Remove from queue.
      echo "sqlite3 /opt/etc/rsqueue.db \"delete from postfixes where serviceid = $serviceid and abs(starttime - $starttime) <= $startstopdiff and abs(stoptime - $stoptime) <= $startstopdiff;\"" >> $trcfile
      sqlite3 /opt/etc/rsqueue.db "delete from postfixes where serviceid = $serviceid and abs(starttime - $starttime) <= $startstopdiff and abs(stoptime - $stoptime) <= $startstopdiff;"
    fi
  else
    echo `date +"%Y-%m-%d %T"` "$f" not found, probably has 8-bit/UTF-8 characters in the name, ignored | tee -a $logfile $trcfile
  fi
done

rm $findtmp

if [ -d "/mnt/hd3/Video/[Dummies]" ]; then
  # Remove dummy recordings for which the queued deletion failed for some reason.
  # Ie, remove dummy recordings that are older than 8 days.

  dir_count=0
  file_count=0
  file_size_total_bytes=0

  files3=`find "/mnt/hd3/Video/[Dummies]" -mtime +7 -name "*.ts" -print`
  echo "$files3" | while read f; do
    if [ "$f" == "*.ts" -o "$f" == "" ]; then
      continue;
    fi

    basename="${f%.ts}"
    erase_file "$basename.ts"
    erase_file "$basename.hmt"
    erase_file "$basename.nts"
    tac_dir=`echo "$basename" | sed 's|\(.*\)/|\1/.|'`
    for tac_file in "$tac_dir/"*; do
      erase_file "$tac_file"
    done
    if [ -d "$tac_dir" ]; then
      dir_count=`expr $dir_count + 1`
      rmdir "$tac_dir"
    fi

    file_size_total_hr=`echo $file_size_total_bytes | rsbs2hr.sh`
    echo `date +"%Y-%m-%d %T"`: "Deleted dummy recording file '$f' ($dir_count dir(s), $file_count file(s), $file_size_total_hr)" | tee -a $logfile

    basename2=`echo "$basename" | sed 's|/mnt/hd3/Video||'`
    logtext="Dummy recording ${basename2}.ts removed ($dir_count dir(s), $file_count file(s), $file_size_total_hr) (scheduled deletion failed)"
    log "$logtext" | tee -a $logfile

    dir_count=0
    file_count=0
    file_size_total_bytes=0
  done
fi

echo `date +"%Y-%m-%d %T"` rsrecmon "$1" stopped >> $logfile
