#!/bin/sh

# Determines pending schedules by comparing fields 1, 4-6 and 9 from rsv output
# between a snapshot from boot and now.

rsvboot=/opt/tmp/rsvp.orig.txt
rsvnow=/opt/tmp/rsvp.now.txt

# Now.
/opt/bin/rsv -p /mnt/hd1/reserve.info | sort -k 2,4 > $rsvnow

# Save output to a file, then print the file. For some reason we only grab the
# first line if done directly.
tmpfile=/opt/tmp/rsvpending.txt
rm $tmpfile > /dev/null 2>&1
tmpfilesupp=/opt/tmp/rsvpendingsupp.txt
rm $tmpfilesupp > /dev/null 2>&1

# Added. Show prefixed with a '+'.
added="`awk 'BEGIN{OFS="\t";FS="\t";}NR==FNR{c[$1$4$5$6$7$9]++;next};c[$1$4$5$6$7$9] == 0' $rsvboot $rsvnow`"
echo "$added" | while read line; do
  if [ "$line" = "" ]; then
    continue;
  fi
  echo "+$line" >> $tmpfile
done

# Removed. Show prefixed with a '-'.
now=`date +"%s"`
removed="`awk 'BEGIN{OFS="\t";FS="\t";}NR==FNR{c[$1$4$5$6$7$9]++;next};c[$1$4$5$6$7$9] == 0' $rsvnow $rsvboot`"
echo "$removed" | while read line; do
  if [ "$line" = "" ]; then
    continue;
  fi
  type=`echo "$line" | cut -f 6`
  stop=`echo "$line" | cut -f 3`
  if [ $type = "ONCE" -o $type = "ECRID" ]; then
    if [ $stop -lt $now ]; then
      # Hide one offs (manual ONCE or ECRID-based) that are in the past.
      echo "#$line" >> $tmpfilesupp
      continue;
    fi
  fi
  echo "-$line" >> $tmpfile
done

# Show result, if any.
if [ -f $tmpfile ]; then
  cat $tmpfile
elif [ -f /tmp/.restartpending ]; then
  # We have pending changes but we don't know which, create one remove dummy as this is probably an event that will be removed after reboot.
  now=`date +%s`
  first_channel=`sqlite3 file:/opt/epg/channels.db?mode=ro "select usLcn, aucDefaultAuthority from tbl_svc_x where usLcn = (select min(usLcn) from tbl_svc_x);"`
  first_channel_lcn=`echo "$first_channel" | cut -d\| -f 1`
  first_channel_auth=`echo "$first_channel" | cut -d\| -f 2`
  dummy="000\t$now\t$now\t$first_channel_lcn\t2080\tECRID\tReboot Pending\t00000\t$first_channel_auth/DUMMY\tfp.bbc.co.uk/DUMMY|\tReboot Pending\t$now|\t$now|"
  echo -e "-$dummy" > $tmpfile
else
  touch $tmpfile
fi
